@@ -4,6 +4,7 @@ import unittest
 import shutil
 import os
 import re
+import sys
 import tarfile
 import tempfile
 import zipfile
@@ -113,6 +114,11 @@ class TestGetMeta(unittest.TestCase):
         meta = p.get_meta()
         self.assertEqual(meta['Comment'], 'Created with GIMP')
 
+    def test_webp(self):
+        p = images.WEBPParser('./tests/data/dirty.webp')
+        meta = p.get_meta()
+        self.assertEqual(meta['Warning'], '[minor] Improper EXIF header')
+
     def test_ppm(self):
         p = images.PPMParser('./tests/data/dirty.ppm')
         meta = p.get_meta()
@@ -333,6 +339,11 @@ class TestCleaning(unittest.TestCase):
             'parser': images.JPGParser,
             'meta': {'Comment': 'Created with GIMP'},
             'expected_meta': {},
+        #}, {
+        #    'name': 'webp',
+        #    'parser': images.WEBPParser,
+        #    'meta': {'Warning': '[minor] Improper EXIF header'},
+        #    'expected_meta': {},
         }, {
             'name': 'wav',
             'parser': audio.WAVParser,
@@ -526,7 +537,40 @@ class TestCleaning(unittest.TestCase):
             'parser': images.HEICParser,
             'meta': {},
             'expected_meta': {
+                'BlueMatrixColumn': '0.14305 0.06061 0.71393',
+                'BlueTRC': '(Binary data 32 bytes, use -b option to extract)',
+                'CMMFlags': 'Not Embedded, Independent',
+                'ChromaticAdaptation': '1.04788 0.02292 -0.05022 0.02959 0.99048 -0.01707 -0.00925 0.01508 0.75168',
+                'ChromaticityChannel1': '0.64 0.33002',
+                'ChromaticityChannel2': '0.3 0.60001',
+                'ChromaticityChannel3': '0.15001 0.06',
+                'ChromaticityChannels': 3,
+                'ChromaticityColorant': 'Unknown',
+                'ColorSpaceData': 'RGB ',
+                'ConnectionSpaceIlluminant': '0.9642 1 0.82491',
+                'DeviceAttributes': 'Reflective, Glossy, Positive, Color',
+                'DeviceManufacturer': '',
+                'DeviceMfgDesc': 'GIMP',
+                'DeviceModel': '',
+                'DeviceModelDesc': 'sRGB',
                 'ExifByteOrder': 'Big-endian (Motorola, MM)',
+                'GreenMatrixColumn': '0.38512 0.7169 0.09706',
+                'GreenTRC': '(Binary data 32 bytes, use -b option to extract)',
+                'MediaWhitePoint': '0.9642 1 0.82491',
+                'PrimaryPlatform': 'Apple Computer Inc.',
+                'ProfileCMMType': 'Little CMS',
+                'ProfileClass': 'Display Device Profile',
+                'ProfileConnectionSpace': 'XYZ ',
+                'ProfileCopyright': 'Public Domain',
+                'ProfileCreator': 'Little CMS',
+                'ProfileDateTime': '2022:05:15 16:29:22',
+                'ProfileDescription': 'GIMP built-in sRGB',
+                'ProfileFileSignature': 'acsp',
+                'ProfileID': 0,
+                'ProfileVersion': '4.3.0',
+                'RedMatrixColumn': '0.43604 0.22249 0.01392',
+                'RedTRC': '(Binary data 32 bytes, use -b option to extract)',
+                'RenderingIntent': 'Perceptual',
                 'Warning': 'Bad IFD0 directory',
             },
         }
@@ -563,13 +607,13 @@ class TestCleaning(unittest.TestCase):
                 meta = p2.get_meta()
                 if meta:
                     for k, v in p2.get_meta().items():
-                        self.assertIn(k, case['expected_meta'], '"%s" is not in "%s" (%s)' % (k, case['expected_meta'], case['name']))
+                        self.assertIn(k, case['expected_meta'], '"%s" is not in "%s" (%s), with all of them being %s' % (k, case['expected_meta'], case['name'], p2.get_meta().items()))
                         if str(case['expected_meta'][k]) in str(v):
                             continue
                         if 'extra_expected_meta' in case and k in case['extra_expected_meta']:
                             if str(case['extra_expected_meta'][k]) in str(v):
                                 continue
-                        self.assertTrue(False, "got a different value (%s) than excepted (%s) for %s" % (str(v), meta, k))
+                        self.assertTrue(False, "got a different value (%s) than excepted (%s) for %s, with all of them being %s" % (str(v), meta, k, p2.get_meta().items()))
                 self.assertTrue(p2.remove_all())
 
                 os.remove(target)
@@ -595,14 +639,20 @@ class TestCleaning(unittest.TestCase):
         os.remove('./tests/data/clean.cleaned.html')
         os.remove('./tests/data/clean.cleaned.cleaned.html')
 
-        with open('./tests/data/clean.html', 'w') as f:
-            f.write('<title><title><pouet/><meta/></title></title><test/>')
-        p = web.HTMLParser('./tests/data/clean.html')
-        self.assertTrue(p.remove_all())
-        with open('./tests/data/clean.cleaned.html', 'r') as f:
-            self.assertEqual(f.read(), '<title></title><test/>')
+        if sys.version_info >= (3, 13):
+            with open('./tests/data/clean.html', 'w') as f:
+                f.write('<title><title><pouet/><meta/></title></title><test/>')
+            with self.assertRaises(ValueError):
+                p = web.HTMLParser('./tests/data/clean.html')
+        else:
+            with open('./tests/data/clean.html', 'w') as f:
+                f.write('<title><title><pouet/><meta/></title></title><test/>')
+            p = web.HTMLParser('./tests/data/clean.html')
+            self.assertTrue(p.remove_all())
+            with open('./tests/data/clean.cleaned.html', 'r') as f:
+                self.assertEqual(f.read(), '<title></title><test/>')
+            os.remove('./tests/data/clean.cleaned.html')
         os.remove('./tests/data/clean.html')
-        os.remove('./tests/data/clean.cleaned.html')
 
         with open('./tests/data/clean.html', 'w') as f:
             f.write('<test><title>Some<b>metadata</b><br/></title></test>')
@@ -820,45 +870,6 @@ class TestCleaningArchives(unittest.TestCase):
         os.remove('./tests/data/dirty.cleaned.tar.xz')
         os.remove('./tests/data/dirty.cleaned.cleaned.tar.xz')
 
-class TestNoSandbox(unittest.TestCase):
-    def test_avi_nosandbox(self):
-        shutil.copy('./tests/data/dirty.avi', './tests/data/clean.avi')
-        p = video.AVIParser('./tests/data/clean.avi')
-        p.sandbox = False
-
-        meta = p.get_meta()
-        self.assertEqual(meta['Software'], 'MEncoder SVN-r33148-4.0.1')
-
-        ret = p.remove_all()
-        self.assertTrue(ret)
-
-        p = video.AVIParser('./tests/data/clean.cleaned.avi')
-        self.assertEqual(p.get_meta(), {})
-        self.assertTrue(p.remove_all())
-
-        os.remove('./tests/data/clean.avi')
-        os.remove('./tests/data/clean.cleaned.avi')
-        os.remove('./tests/data/clean.cleaned.cleaned.avi')
-
-    def test_png_nosandbox(self):
-        shutil.copy('./tests/data/dirty.png', './tests/data/clean.png')
-        p = images.PNGParser('./tests/data/clean.png')
-        p.sandbox = False
-        p.lightweight_cleaning = True
-
-        meta = p.get_meta()
-        self.assertEqual(meta['Comment'], 'This is a comment, be careful!')
-
-        ret = p.remove_all()
-        self.assertTrue(ret)
-
-        p = images.PNGParser('./tests/data/clean.cleaned.png')
-        self.assertEqual(p.get_meta(), {})
-        self.assertTrue(p.remove_all())
-
-        os.remove('./tests/data/clean.png')
-        os.remove('./tests/data/clean.cleaned.png')
-        os.remove('./tests/data/clean.cleaned.cleaned.png')
 
 class TestComplexOfficeFiles(unittest.TestCase):
     def test_complex_pptx(self):
